# -*- coding: utf-8 -*-

"""
Module required for Django to recognize ``donottrack`` as an app.

And that is necessary for tests to run. This module serves no other purpose.

"""

from __future__ import unicode_literals
